import click
from rich.console import Console
from rich.table import Table

console = Console()

@click.group()
def cli():
    """DBForge - A command-line tool for managing databases"""
    pass

@cli.command()
def list():
    """List all configured databases"""
    table = Table(title="Configured Databases")
    table.add_column("Name", style="cyan")
    table.add_column("Type", style="green")
    table.add_column("Status", style="yellow")
    
    # Example data - will be replaced with actual DB configs later
    table.add_row("example_db", "PostgreSQL", "Not Connected")
    
    console.print(table)

@cli.command()
@click.argument('name')
@click.option('--type', '-t', default='postgres', help='Database type (postgres, mysql, etc)')
def create(name, type):
    """Create a new database configuration"""
    console.print(f"Creating new {type} database: [cyan]{name}[/cyan]")

if __name__ == '__main__':
    cli()
